@@ -1,3 +1,6 @@
+import time
+
+
 class Action(object):
     def __init__(self, conn):
         self.conn = conn
@@ -67,4 +70,10 @@ class api(object):
 
     def set(self, *args, **kwargs):
         getattr(self, '%s_set' % self.action_name)(*args, **kwargs)
-        return self.get(**kwargs)
+        local = args[0]
+        while True:
+            db = self.get(**kwargs)
+            if len(db) == len(local):
+                break
+            time.sleep(0.2)
+        return db
